pub struct MleVecIndex(usize);Expand description
mid-term solution for deduplication of DenseMleRefs basically a wrapper around usize, which denotes the index of the MleRef in an expression’s MleRef list/// Generic Expressions
TODO(ryancao): We should deprecate this and instead just have
references to the DenseMLE<F>s which are stored in the circuit_map.
Tuple Fields
0: usizeImplementations
Sourceimpl MleVecIndex
impl MleVecIndex
Sourcepub fn get_mle<'a, F: Field>(
&self,
mle_vec: &'a [DenseMle<F>],
) -> &'a DenseMle<F>
pub fn get_mle<'a, F: Field>( &self, mle_vec: &'a [DenseMle<F>], ) -> &'a DenseMle<F>
return the actual mle in the vec within the prover expression
Sourcepub fn get_mle_mut<'a, F: Field>(
&self,
mle_vec: &'a mut [DenseMle<F>],
) -> &'a mut DenseMle<F>
pub fn get_mle_mut<'a, F: Field>( &self, mle_vec: &'a mut [DenseMle<F>], ) -> &'a mut DenseMle<F>
return the actual mle in the vec within the prover expression